summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorEmiel Bruijntjes <emiel.bruijntjes@copernica.com>2014-04-05 18:59:02 +0200
committerEmiel Bruijntjes <emiel.bruijntjes@copernica.com>2014-04-05 18:59:02 +0200
commitf407d6d4c5ea35f73c5aec72f8b492c259dc7dfe (patch)
tree0dcc05c86bf24ea36e5a5c9b9283535baca8454c /src
parent5d84ff5483f2db57762311714ff3c779db1e0f96 (diff)
renamed iteratorimpl to valueiteratorimpl to make room for the upcoming iteratorimpl class
Diffstat (limited to 'src')
-rw-r--r--src/hashiterator.h8
-rw-r--r--src/includes.h2
-rw-r--r--src/invaliditerator.h8
-rw-r--r--src/iterator.cpp4
-rw-r--r--src/traverseiterator.h8
-rw-r--r--src/valueiteratorimpl.h (renamed from src/iteratorimpl.h)16
6 files changed, 23 insertions, 23 deletions
diff --git a/src/hashiterator.h b/src/hashiterator.h
index d68ad4e..b1f409f 100644
--- a/src/hashiterator.h
+++ b/src/hashiterator.h
@@ -20,7 +20,7 @@ namespace Php {
/**
* Class definition
*/
-class HashIterator : public IteratorImpl
+class HashIterator : public ValueIteratorImpl
{
public:
/**
@@ -70,9 +70,9 @@ public:
/**
* Clone the object
* @param tsrm_ls
- * @return IteratorImpl
+ * @return ValueIteratorImpl
*/
- virtual IteratorImpl *clone()
+ virtual ValueIteratorImpl *clone()
{
// create a new instance
return new HashIterator(*this);
@@ -136,7 +136,7 @@ public:
* @param that
* @return bool
*/
- virtual bool equals(const IteratorImpl *that) const override
+ virtual bool equals(const ValueIteratorImpl *that) const override
{
// this always is a hash iterator
HashIterator *other = (HashIterator *)that;
diff --git a/src/includes.h b/src/includes.h
index 10dd4b8..ace1401 100644
--- a/src/includes.h
+++ b/src/includes.h
@@ -93,7 +93,7 @@
#include "origexception.h"
#include "notimplemented.h"
#include "property.h"
-#include "iteratorimpl.h"
+#include "valueiteratorimpl.h"
#include "hashiterator.h"
#include "invaliditerator.h"
#include "traverseiterator.h"
diff --git a/src/invaliditerator.h b/src/invaliditerator.h
index 7531d7d..388eca8 100644
--- a/src/invaliditerator.h
+++ b/src/invaliditerator.h
@@ -16,15 +16,15 @@ namespace Php {
/**
* Class definition
*/
-class InvalidIterator : public IteratorImpl
+class InvalidIterator : public ValueIteratorImpl
{
public:
/**
* Clone the object
* @param tsrm_ls
- * @return IteratorImpl
+ * @return ValueIteratorImpl
*/
- virtual IteratorImpl *clone()
+ virtual ValueIteratorImpl *clone()
{
// create a new instance
return new InvalidIterator(*this);
@@ -54,7 +54,7 @@ public:
* @param that
* @return bool
*/
- virtual bool equals(const IteratorImpl *that) const override
+ virtual bool equals(const ValueIteratorImpl *that) const override
{
// the other iterator is also an invalid-iterator, and all invalid
// iterators are equal
diff --git a/src/iterator.cpp b/src/iterator.cpp
index 0362fb1..d797924 100644
--- a/src/iterator.cpp
+++ b/src/iterator.cpp
@@ -1,7 +1,7 @@
/**
- * IteratorImpl.cpp
+ * Iterator.cpp
*
- * Implementation file of the IteratorImpl class
+ * Implementation file of the Iterator class
*
* @author Emiel Bruijntjes <emiel.bruijntjes@copernica.com>
* @copyright 2014 Copernica BV
diff --git a/src/traverseiterator.h b/src/traverseiterator.h
index 84c50f0..16f1ce7 100644
--- a/src/traverseiterator.h
+++ b/src/traverseiterator.h
@@ -17,7 +17,7 @@ namespace Php {
/**
* Class definition
*/
-class TraverseIterator : public IteratorImpl
+class TraverseIterator : public ValueIteratorImpl
{
public:
/**
@@ -73,9 +73,9 @@ public:
/**
* Clone the object
* @param tsrm_ls
- * @return IteratorImpl*
+ * @return ValueIteratorImpl*
*/
- virtual IteratorImpl *clone() override
+ virtual ValueIteratorImpl *clone() override
{
// we need the tsrm_ls variable
TSRMLS_FETCH();
@@ -119,7 +119,7 @@ public:
* @param that
* @return bool
*/
- virtual bool equals(const IteratorImpl *that) const override
+ virtual bool equals(const ValueIteratorImpl *that) const override
{
// of course if the objects are identical
if (this == that) return true;
diff --git a/src/iteratorimpl.h b/src/valueiteratorimpl.h
index babf9f0..7de2443 100644
--- a/src/iteratorimpl.h
+++ b/src/valueiteratorimpl.h
@@ -1,7 +1,7 @@
/**
- * IteratorImpl.h
+ * ValueIteratorImpl.h
*
* Interface that describes what an implementation of an iterator should
* look like. This is an internal class that extension developers do not
* need.
*
@@ -17,25 +17,25 @@ namespace Php {
/**
* Class definition
*/
-class IteratorImpl
+class ValueIteratorImpl
{
public:
/**
* Constructor
*/
- IteratorImpl() {}
+ ValueIteratorImpl() {}
/**
* Destructor
*/
- virtual ~IteratorImpl() {}
+ virtual ~ValueIteratorImpl() {}
/**
* Clone the object
* @param tsrm_ls
- * @return IteratorImpl*
+ * @return ValueIteratorImpl*
*/
- virtual IteratorImpl *clone() = 0;
+ virtual ValueIteratorImpl *clone() = 0;
/**
* Increment position (pre-increment)
@@ -55,7 +55,7 @@ public:
* @param that
* @return bool
*/
- virtual bool equals(const IteratorImpl *that) const = 0;
+ virtual bool equals(const ValueIteratorImpl *that) const = 0;
/**
* Derefecence, this returns a std::pair with the current key and value
@@ -1,7 +1,7 @@
*
- * Interface that describes what an implementation of an iterator should
+ * Interface that describes what an implementation of a value iterator should
* look like. This is an internal class that extension developers do not
* need.